@@ -50,6 +50,7 @@ class CPWord(MIDITokenizer):
                  sos_eos_tokens: bool = False, mask: bool = False, params=None):
         # Indexes of additional token types within a compound token
         add_idx = 5
+        additional_tokens['TimeSignature'] = False  # not compatible
         self.program_ixd = self.chord_idx = self.rest_idx = self.tempo_idx = None
         if additional_tokens['Program']:
             self.program_ixd = add_idx
@@ -255,7 +256,7 @@ class CPWord(MIDITokenizer):
         for compound_token in events:
             token_family = compound_token[0].value
             if token_family == 'Note':
-                if any(tok.value == 'None' for tok in compound_token[1:5]):
+                if any(tok.value in ['None', 'Ignore'] for tok in compound_token[2:5]):
                     continue
                 pitch = int(compound_token[2].value)
                 vel = int(compound_token[3].value)
@@ -274,7 +275,7 @@ class CPWord(MIDITokenizer):
                         tempo = int(compound_token[-1].value)
                         if tempo != tempo_changes[-1].tempo:
                             tempo_changes.append(TempoChange(tempo, current_tick))
-                elif compound_token[self.rest_idx].value != 'Ignore':  # i.e. its a rest
+                elif self.additional_tokens['Rest'] and compound_token[self.rest_idx].value != 'Ignore':
                     if current_tick < previous_note_end:  # if in case successive rest happen
                         current_tick = previous_note_end
                     beat, pos = map(int, compound_token[self.rest_idx].value.split('.'))
