@@ -13,7 +13,7 @@ from miditoolkit import MidiFile, Instrument, Note, TempoChange
 
 from .midi_tokenizer_base import MIDITokenizer
 from .vocabulary import Vocabulary, Event
-from .utils import detect_chords, remove_duplicated_notes
+from .utils import detect_chords
 from .constants import *
 
 
@@ -43,6 +43,7 @@ class MuMIDI(MIDITokenizer):
                  programs: List[int] = None, sos_eos_tokens: bool = False, mask: bool = False, params=None,
                  drum_pitch_range: range = DRUM_PITCH_RANGE):
         additional_tokens['Rest'] = False
+        additional_tokens['TimeSignature'] = False  # not compatible
         self.drum_pitch_range = drum_pitch_range
         self.programs = list(range(-1, 128)) if programs is None else programs
         # used in place of positional encoding
@@ -198,15 +199,15 @@ class MuMIDI(MIDITokenizer):
         for note in track.notes:
             # Note
             duration = note.end - note.start
-            dur_index = np.argmin(np.abs(dur_bins - duration))
+            dur_idx = np.argmin(np.abs(dur_bins - duration))
             if not track.is_drum:
                 tokens.append([Event(type_='Pitch', time=note.start, value=note.pitch, desc=track.program),
                                self.vocab[1].event_to_token[f'Velocity_{note.velocity}'],
-                               self.vocab[2].event_to_token[f'Duration_{".".join(map(str, self.durations[dur_index]))}']])
+                               self.vocab[2].event_to_token[f'Duration_{".".join(map(str, self.durations[dur_idx]))}']])
             else:
                 tokens.append([Event(type_='DrumPitch', time=note.start, value=note.pitch, desc=-1),
                                self.vocab[1].event_to_token[f'Velocity_{note.velocity}'],
-                               self.vocab[2].event_to_token[f'Duration_{".".join(map(str, self.durations[dur_index]))}']])
+                               self.vocab[2].event_to_token[f'Duration_{".".join(map(str, self.durations[dur_idx]))}']])
 
         # Adds chord tokens if specified
         if self.additional_tokens['Chord'] and not track.is_drum:
@@ -406,6 +407,9 @@ class MuMIDI(MIDITokenizer):
         for token in tokens[1:]:
             if not consider_pad and previous_type == 'PAD':
                 break
+            if any(self.vocab[i][token].split('_')[0] in ['PAD', 'MASK'] for i, token in enumerate(token)):
+                err += 1
+                continue
             bar_value = int(self.vocab[4].token_to_event[token[bar_idx]].split('_')[1])
             pos_value = self.vocab[3].token_to_event[token[pos_idx]].split('_')[1]
             pos_value = int(pos_value) if pos_value != 'Ignore' else -1
