@@ -55,6 +55,8 @@ class Octuple(MIDITokenizer):
                        'beat_res': {f'{k1}_{k2}': v for (k1, k2), v in self.beat_res.items()},
                        'nb_velocities': len(self.velocities),
                        'additional_tokens': self.additional_tokens,
+                       '_sos_eos': self._sos_eos,
+                       '_mask': self._mask,
                        'encoding': self.__class__.__name__,
                        'programs': self.programs,
                        'max_bar_embedding': self.max_bar_embedding},
@@ -344,7 +346,7 @@ class Octuple(MIDITokenizer):
         vocab[2].add_event(f'Duration_{".".join(map(str, duration))}' for duration in self.durations)
 
         # PROGRAM
-        vocab[3].add_event(f'Program_{i}' for i in range(-1, 128))
+        vocab[3].add_event(f'Program_{i}' for i in self.programs)
 
         # POSITION
         nb_positions = max(self.beat_res.values()) * 4  # 4/4 time signature
@@ -374,7 +376,7 @@ class Octuple(MIDITokenizer):
         """
         return {}  # not relevant for this encoding
 
-    def token_types_errors(self, tokens: List[List[int]]) -> float:
+    def token_types_errors(self, tokens: List[List[int]], consider_pad: bool = False) -> float:
         r"""Checks if a sequence of tokens is constituted of good token values and
         returns the error ratio (lower is better).
         The token types are always the same in Octuple so this methods only checks
@@ -384,17 +386,24 @@ class Octuple(MIDITokenizer):
             - a pitch token should not be present if the same pitch is already played at the current position
 
         :param tokens: sequence of tokens to check
+        :param consider_pad: if True will continue the error detection after the first PAD token (default: False)
         :return: the error ratio (lower is better)
         """
         err = 0
         current_bar = current_pos = -1
-        current_pitches = []
+        current_pitches = {p: [] for p in self.programs}
 
         for token in tokens:
+            if consider_pad and all(token[i] == self.vocab[i]['PAD_None'] for i in range(len(token))):
+                break
+            if any(self.vocab[i][token].split('_')[1] == 'None' for i, token in enumerate(token)):
+                err += 1
+                continue
             has_error = False
             bar_value = int(self.vocab[5].token_to_event[token[5]].split('_')[1])
             pos_value = int(self.vocab[4].token_to_event[token[4]].split('_')[1])
             pitch_value = int(self.vocab[0].token_to_event[token[0]].split('_')[1])
+            program_value = int(self.vocab[0].token_to_event[token[0]].split('_')[1])
 
             # Bar
             if bar_value < current_bar:
@@ -402,20 +411,20 @@ class Octuple(MIDITokenizer):
             elif bar_value > current_bar:
                 current_bar = bar_value
                 current_pos = -1
-                current_pitches = []
+                current_pitches = {p: [] for p in self.programs}
 
             # Position
             if pos_value < current_pos:
                 has_error = True
             elif pos_value > current_pos:
                 current_pos = pos_value
-                current_pitches = []
+                current_pitches = {p: [] for p in self.programs}
 
             # Pitch
             if pitch_value in current_pitches:
                 has_error = True
             else:
-                current_pitches.append(pitch_value)
+                current_pitches[program_value].append(pitch_value)
 
             if has_error:
                 err += 1
