@@ -56,6 +56,8 @@ class OctupleMono(MIDITokenizer):
                        'beat_res': {f'{k1}_{k2}': v for (k1, k2), v in self.beat_res.items()},
                        'nb_velocities': len(self.velocities),
                        'additional_tokens': self.additional_tokens,
+                       '_sos_eos': self._sos_eos,
+                       '_mask': self._mask,
                        'encoding': self.__class__.__name__,
                        'max_bar_embedding': self.max_bar_embedding},
                       outfile)
@@ -229,7 +231,7 @@ class OctupleMono(MIDITokenizer):
         """
         return {}  # not relevant for this encoding
 
-    def token_types_errors(self, tokens: List[List[int]]) -> float:
+    def token_types_errors(self, tokens: List[List[int]], consider_pad: bool = False) -> float:
         r"""Checks if a sequence of tokens is constituted of good token values and
         returns the error ratio (lower is better).
         The token types are always the same in Octuple so this methods only checks
@@ -239,6 +241,7 @@ class OctupleMono(MIDITokenizer):
             - a pitch token should not be present if the same pitch is already played at the current position
 
         :param tokens: sequence of tokens to check
+        :param consider_pad: if True will continue the error detection after the first PAD token (default: False)
         :return: the error ratio (lower is better)
         """
         err = 0
@@ -246,6 +249,11 @@ class OctupleMono(MIDITokenizer):
         current_pitches = []
 
         for token in tokens:
+            if consider_pad and all(token[i] == self.vocab[i]['PAD_None'] for i in range(len(token))):
+                break
+            if any(self.vocab[i][token].split('_')[1] == 'None' for i, token in enumerate(token)):
+                err += 1
+                continue
             has_error = False
             bar_value = int(self.vocab[4].token_to_event[token[4]].split('_')[1])
             pos_value = int(self.vocab[3].token_to_event[token[3]].split('_')[1])
